import { defineStore, mapStores } from 'pinia';

export const useLayoutStore = defineStore('layout', {
    state: () => ({
        minDesktopWidth: 992,
        isDesktop: Boolean,
        isEtapeListRetracted: Boolean,
        isEtapeListeScrollable: false,
        isHamburgerMenuOpen: false,
    }),
    actions: {
        setupResizeListenner () {
            this.isDesktop = window.innerWidth >= this.minDesktopWidth ? true : false;
            window.addEventListener('resize', () => {
                this.isDesktop = window.innerWidth >= this.minDesktopWidth ? true : false;
            })
            this.isEtapeListRetracted = this.isDesktop ? false : true;
        },
        collapseEtapeListe(listeEtape, animationToggle) {
            listeEtape.classList.add('retracted');
            animationToggle.classList.add('hidden');
            setTimeout(() => {
                listeEtape.closest('.layout__region').classList.add('retracted');
                listeEtape.nextElementSibling.classList.add('retracted');
                listeEtape.classList.add('disapeared');
            }, 300);
            this.isEtapeListRetracted = true;
        },
        expandEtapeListe(listeEtape, animationToggle) {
            listeEtape.closest('.layout__region').classList.remove('retracted');
            listeEtape.nextElementSibling.classList.remove('retracted');
            listeEtape.classList.remove('disapeared');
            animationToggle.classList.remove('hidden');
            setTimeout(() => {
                listeEtape.classList.remove('retracted');
            }, 300);
            this.isEtapeListRetracted = false;
        },
        shouldEtapeListeScroll({ listeEtape, column, listeEtapeContent, header, animationToggle }) {
          const columnRect = column.getBoundingClientRect();
          const listeEtapeContentRect = listeEtapeContent.getBoundingClientRect();
          const headerRect = header.getBoundingClientRect();
          const animationToggleRect = animationToggle.getBoundingClientRect();

          const isIntersecting = headerRect.bottom >= (columnRect.height - listeEtapeContentRect.height) / 2;    

          this.toggleEtapeListScroll(isIntersecting, listeEtape, column, headerRect.height, animationToggleRect.top);
        },
        toggleEtapeListScroll(isIntersecting, listeEtape, column, headerHeight, animationToggleTop) {
          if (isIntersecting && !this.isEtapeListeScrollable 
          || !isIntersecting && this.isEtapeListeScrollable) {
            listeEtape.classList.toggle('scrollable');
            column.classList.toggle('liste-etapes-scrollable');
            this.isEtapeListeScrollable = !this.isEtapeListeScrollable;
          }

          listeEtape.style.marginTop = isIntersecting ? `${headerHeight}px` : 'unset';
          listeEtape.style.maxHeight = isIntersecting ? `calc(100vh - (100vh - ${animationToggleTop}px) - ${headerHeight}px)` : 'unset';
        },
        setUpHamburgerToggle(menuBurger, menuContainer) {
          const menuTitle = document.querySelector('#menu-title');
          const menuH2 = document.querySelector('#menu > h2');

          menuContainer.style.display = 'none';

          menuBurger.addEventListener('click', (e) => {
            this.toggleHamburgerMenu(menuBurger, menuContainer, menuTitle, menuH2);
          });
          document.addEventListener('click', (e) => {
            if (
              (!menuContainer.contains(e.target) && !menuBurger.contains(e.target))
              || e.target.tagName === 'A'
            ) {
              menuContainer.classList.remove('open');
              menuTitle.classList.remove('open');
              menuBurger.classList.remove('open');
              menuH2.classList.remove('open');
              if (this.isHamburgerMenuOpen) {
                setTimeout(() => {
                  menuContainer.style.display = 'none';
                }, 300);
                this.isHamburgerMenuOpen = false;
              }
            }
          });
        },
        toggleHamburgerMenu(menuBurger, menuContainer, menuTitle, menuH2) {
          setTimeout(() => {
            if (!this.isHamburgerMenuOpen) menuContainer.style.display = 'block';
            setTimeout(() => {
              menuContainer.classList.toggle('open');
              menuTitle.classList.toggle('open');
              menuBurger.classList.toggle('open');
              menuH2.classList.toggle('open');
              if (this.isHamburgerMenuOpen) {
                setTimeout(() => {
                  menuContainer.style.display = 'none';
                }, 300);
              }
              this.isHamburgerMenuOpen = !this.isHamburgerMenuOpen;
            }, 50);
          }, 50);
        },
        setHeaderPosition(currentPageIsIndex) {
          const header = document.querySelector('.layout-container > header');
          header.style.position = currentPageIsIndex ? 'fixed' : 'relative';
        }
    },
})
