import { setActiveNavItem } from "./set-active-nav-item";
import { useLayoutStore } from '../stores/layout';

export async function initFirstLoadRouting(store, router, baseUrl, siteName) {
    const decoupled_origin = JSON.parse(window.localStorage.getItem('decoupled_origin'));

    if(decoupled_origin) {
        router.push(decoupled_origin.url);
        await store.fetchContentData(baseUrl + decoupled_origin.url);
        window.localStorage.removeItem("decoupled_origin");
        document.title = store.pageTitle;
        setActiveNavItem(store.contentType, decoupled_origin.url);
        useLayoutStore().setHeaderPosition(false);
    } else {
        document.title = siteName;
        useLayoutStore().setHeaderPosition(true);
    }
}

export function handleClickableElements(clickableElements, store, router, baseUrl, siteName, mapStore) {
    for (const link of clickableElements) {
        let href = link.href || link.dataset.href;
        if (href.startsWith(baseUrl)) href = href.replace(baseUrl, '');

        link.onclick = async function (e) {
            router.push(href);
            if (href !== window.location.pathname) {
              pageChange(href, store, siteName, mapStore, baseUrl);
            }
        }
    }
}

export async function handleBrowserNavigation(store, baseUrl, siteName, mapStore) {
  let href = window.location.pathname;
  if (href.startsWith(baseUrl)) href = href.replace(baseUrl, '');
  pageChange(href, store, siteName, mapStore, baseUrl)
}

export async function pageChange(href, store, siteName, mapStore, baseUrl) {
  if (href === '/') {
      store.resetStore(true);
      document.title = siteName;
      mapStore.resetMap();
      useLayoutStore().setHeaderPosition(true);
  } else {
      await store.fetchContentData(baseUrl + href);
      document.title = store.pageTitle;
      useLayoutStore().setHeaderPosition(false);
  }
  setActiveNavItem(store.contentType, href);

  const listeEtape = document.querySelector('#etapes-liste');
  const animationToggle = document.querySelector('#animation-toggle');
  if (!useLayoutStore().isDesktop) useLayoutStore().collapseEtapeListe(listeEtape, animationToggle);
}
